@@ -44,11 +44,9 @@ class SspiTest(unittest.TestCase):
 
         token_buf = create_string_buffer(10000)
         bufs = [(pytds.sspi.SECBUFFER_TOKEN, token_buf)]
-        server = settings.HOST
-        if "\\" in server:
-            server, _ = server.split("\\")
-        host, _, _ = socket.gethostbyname_ex(server)
-        target_name = "MSSQLSvc/{0}:1433".format(host)
+        # getting current host's name
+        host, _, _ = socket.gethostbyname_ex("")
+        target_name = f"MSSQLSvc/{host}:1433"
         ctx, status, bufs = cred.create_context(
             flags=pytds.sspi.ISC_REQ_CONFIDENTIALITY
             | pytds.sspi.ISC_REQ_REPLAY_DETECT
